@@ -42,12 +42,8 @@ static VALUE mm_str(VALUE obj, int modify) {
     GET_MMAP(obj, i_mm, modify & ~MM_ORIGIN);
     if (modify & MM_MODIFY) {
         if (i_mm->t->flag & MM_FROZEN) rb_error_frozen("mmap");
-        if (!OBJ_TAINTED(ret) && rb_safe_level() >= 4) rb_raise(rb_eSecurityError, "Insecure: can't modify mmap");
     }
     ret = rb_obj_alloc(rb_cString);
-    if (rb_obj_tainted(obj)) {
-        OBJ_TAINT(ret);
-    }
     RSTRING(ret)->as.heap.ptr = i_mm->t->addr;
     RSTRING(ret)->as.heap.aux.capa = i_mm->t->len;
     RSTRING(ret)->as.heap.len = i_mm->t->real;
@@ -216,13 +212,6 @@ VALUE mm_init(VALUE obj, VALUE fname) {
     SafeStringValue(fname);
     path = StringValuePtr(fname);
 
-    {
-        if (rb_safe_level() > 0 && OBJ_TAINTED(fname)) {
-            rb_raise(rb_eSecurityError, "Insecure operation");
-        }
-        rb_secure(1);
-    }
-
     vscope = MAP_SHARED;
     size = 0;
     perm = 0666;
@@ -280,7 +269,6 @@ VALUE mm_init(VALUE obj, VALUE fname) {
     if (smode == O_WRONLY) {
         i_mm->t->flag |= MM_FIXED;
     }
-    OBJ_TAINT(obj);
     return obj;
 }
 
